@@ -15,7 +15,7 @@ along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA */
 
 typedef struct treil_tree {
-  long size;
+  unsigned long long size;
   char *name;
   short depth;
   struct treil_tree *sibling, *children, *parent;
